/* 
   create_output.m

   This file contains the create_output function.  This function
   either creates a serialized property list or dumps the property
   list to standard out based on whether or not the -output option
   is specified.

   Copyright (C) 1996,1999,2000 Free Software Foundation, Inc.

   Author:  Gregory John Casamento
   Date: 17 Jan 2000
   
   This file is part of GNUstep

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

/* ToolMain.m created by heron on Wed 12-Jan-2000 */
#import <Foundation/Foundation.h>

void create_output( id propertyList )
{
    NSFileHandle *fileHandle = nil;
    NSProcessInfo *processInfo = [NSProcessInfo processInfo];
    NSArray *arguments = [processInfo arguments];
    int outputIndex = 0;

    // insert your code here
    outputIndex = [arguments indexOfObject: @"-output"];
    if( outputIndex == NSNotFound )
    {
        const char *buffer = [[propertyList description] cString];
        NSData *outputData = [NSData dataWithBytes: buffer length: strlen(buffer)];
        
        // setup the file handle.
        fileHandle = [NSFileHandle fileHandleWithStandardOutput];
        // Send the data to stdout
        [fileHandle writeData: outputData];
        puts("\n");
    }
    else
    {
        NSData *serializedData = nil;
        NSFileManager *fileManager = [NSFileManager defaultManager];

        // Write in the serialized plist.
        serializedData = [NSSerializer serializePropertyList: propertyList];
        [fileManager createFileAtPath: [arguments objectAtIndex: outputIndex+1]
                             contents: serializedData
                           attributes: nil];
    }
}
