/* 
   process_plist.m

   This file contains the process_plist() function.  This function takes
   the data which was read in from the input file and turns it into the
   appropriate plist object (NSString, NSDictionary, NSArray, NSData) and
   returns it as an id.  It also has a NS_DURING block to enable it to
   catch any problems with the plist while it is being converted and report
   those problems to the user.

   Copyright (C) 1996,1999,2000 Free Software Foundation, Inc.

   Author:  Gregory John Casamento
   Date: 17 Jan 2000
   
   This file is part of GNUstep

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

/* ToolMain.m created by heron on Wed 12-Jan-2000 */
#import <Foundation/Foundation.h>

id process_plist( NSData *inputData )
{
    id propertyList = nil;
    NSString *string = nil;

    // Initialize a string with the contents of the file.
    string = [NSString stringWithCString: (char *)[inputData bytes]];

    // Convert the string into a property list.  If there is a parsing error
    // the property list interpreter will throw an exception.
    NS_DURING
        propertyList = [string propertyList];
    NS_HANDLER
        NSLog([localException description]);
    NS_ENDHANDLER
	
    // return the results
    return propertyList;
}
