/* 
   read_input.m

   Read the input file based on whether the -input option is
   specified.  Thie function will read stdin, if no serialized
   file is given.

   Copyright (C) 1996,1999,2000 Free Software Foundation, Inc.

   Author:  Gregory John Casamento
   Date: 17 Jan 2000
   
   This file is part of GNUstep

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

/* ToolMain.m created by heron on Wed 12-Jan-2000 */
#import <Foundation/Foundation.h>

NSData *read_input()
{
    NSData *inputData = nil;
    NSFileHandle *fileHandle = nil;
    NSProcessInfo *processInfo = [NSProcessInfo processInfo];
    NSArray *arguments = [processInfo arguments];
    int inputIndex = 0;

    // insert your code here
    inputIndex = [arguments indexOfObject: @"-input"];
    if( inputIndex == NSNotFound )
    {
        // setup the file handle.
        fileHandle = [NSFileHandle fileHandleWithStandardInput];
        // Read in the input from the file.
        inputData = [fileHandle readDataToEndOfFile];
    }
    else
    {
        NSData *serializedData = nil;
        id propertyList = nil;
        char *buffer = 0;

        // set up the file handle.
        fileHandle = [NSFileHandle fileHandleForReadingAtPath: [arguments objectAtIndex: inputIndex+1]];
        // read in the serialized plist.
        serializedData = [fileHandle readDataToEndOfFile];
        [fileHandle closeFile];
        propertyList = [NSDeserializer deserializePropertyListFromData: serializedData
                                                     mutableContainers: NO];
        if( propertyList != nil )
        {
            buffer = (char *)[[propertyList description] cString];
            inputData = [NSData dataWithBytes: buffer length: strlen(buffer)];
        }
        else
        {
            NSLog(@"%@ is not a serialized property list.", [arguments objectAtIndex: inputIndex+1]);
        }
    }

    return inputData;
}
